@@ -26,7 +26,7 @@ def get_proxies(url, proxy_type=None):
 
 def get_http_proxy(url):
     """Create a generator of http proxies."""
-    http_proxies = get_proxies(url, 'http')
+    http_proxies = get_proxies(url, proxy_type='http')
     num_proxies = len(http_proxies)
     i = 0
     while i < num_proxies:
@@ -36,7 +36,7 @@ def get_http_proxy(url):
 
 def get_https_proxy(url):
     """Create a generator of https proxies."""
-    https_proxies = get_proxies(url, 'https')
+    https_proxies = get_proxies(url, proxy_type='https')
     num_proxies = len(https_proxies)
     i = 0
     while i < num_proxies:
